@@ -7,25 +7,34 @@ from requests.adapters import HTTPAdapter
 class get_helper:
     def __init__(self, app):
         self.app = app
+        self.proxies_list = []
+        if self.app.config['proxy']['enable_proxy']:
+            try:
+                with open(self.app.config['proxy']['path'], 'r', encoding='utf-8-sig', newline='') as f:
+                    self.proxies_list = [proxy for proxy in f]
+            except Exception as e:
+                print("not found file with proxies")
+                self.app.log_error.error(e, exc_info=True)
 
     def run(self, url, cookie=None, method='GET', data=None):
         headers = self.app.config['get']['headers']
         headers['user-agent'] = choice(self.app.ua_list)
         proxy = None
+        proxies = None
         if self.app.config['proxy']['enable_proxy']:
-            while True:
-                with open(self.app.config['proxy']['path'], 'r', encoding='utf-8-sig', newline='') as f:
-                    proxies_list = [proxy for proxy in f]
-                proxy = choice(proxies_list)
-                if proxy not in self.app.using_proxies:
+            for i in range(len(self.proxies_list)):
+                if self.proxies_list[i] not in self.app.using_proxies:
+                    proxy = self.proxies_list[i]
                     self.app.using_proxies.append(proxy)
                     break
             if self.app.config['proxy']['proxy_autentification']:
-                proxies = {'https': f"https://{self.app.config['proxy']['login']}:{self.app.config['proxy']['password']}@{proxy}"}
+                if proxy:
+                    proxies = {'https': f"https://{self.app.config['proxy']['login']}:{self.app.config['proxy']['password']}@{proxy}"}
             else:
-                proxies = {"http": f"http://{proxy}", "https": f"https://{proxy}"}
-        else:
-            proxies = None
+                if proxy:
+                    proxies = {"http": f"http://{proxy}", "https": f"https://{proxy}"}
+            if proxies is None:
+                print("There are no free proxies")
         r = None
         status_code = 0
         attempt = 1
